@extends('layouts.app')

@section('css')
	<!-- Telephone Input CSS -->
	<link href="{{URL::asset('plugins/telephoneinput/telephoneinput.css')}}" rel="stylesheet" >
@endsection

@section('page-header')
	<!-- EDIT PAGE HEADER -->
	<div class="page-header mt-5-7">
		<div class="page-leftheader">
			<h4 class="page-title mb-0">{{ __('Edit Team Member') }}</h4>
			<ol class="breadcrumb mb-2">
				<li class="breadcrumb-item"><a href="{{route('user.dashboard')}}"><i class="fa-solid fa-people-arrows mr-2 fs-12"></i>{{ __('User') }}</a></li>
				<li class="breadcrumb-item" aria-current="page"><a href="{{route('user.team')}}"> {{ __('Team Members') }}</a></li>
				<li class="breadcrumb-item active" aria-current="page"><a href="#"> {{ __('Edit Team Member') }}</a></li>
			</ol>
		</div>
	</div>
	<!-- END PAGE HEADER -->
@endsection

@section('content')
	<!-- EDIT USER PROFILE PAGE -->
	<div class="row">
		<div class="col-sm-12">
			<div class="card border-0">
				<div class="card-header">
					<h3 class="card-title">{{ __('Edit Team Member Information') }}</h3>
				</div>
				<div class="card-body pb-0">
					<form method="POST" action="{{ route('user.team.update', [$user->id]) }}" enctype="multipart/form-data">
						@method('PUT')
						@csrf
						<div class="row">
							<div class="col-sm-6 col-md-6">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('Full Name') }}</label>
										<input type="text" class="form-control @error('name') is-danger @enderror" name="name" value="{{ $user->name }}">
										@error('name')
											<p class="text-danger">{{ $errors->first('name') }}</p>
										@enderror									
									</div>
								</div>
							</div>
							<div class="col-sm-6 col-md-6">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('Email Address') }}</label>
										<input type="email" class="form-control @error('email') is-danger @enderror" name="email" value="{{ $user->email }}">
										@error('email')
											<p class="text-danger">{{ $errors->first('email') }}</p>
										@enderror
									</div>
								</div>
							</div>
						</div>

						<div class="row border-top pt-4 mt-3">
							<div class="col-sm-12 col-md-4 pt-3 pb-3">
								<div class="form-group">
									<label class="custom-switch mb-0">
										<input type="checkbox" name="template" class="custom-switch-input" @if ($user->member_use_credits_template) checked @endif>
										<span class="custom-switch-indicator"></span>
										<span class="custom-switch-description">{{ __('Allow Credits for Templates') }}</span>
									</label>
								</div>
							</div>
							@if (config('settings.chat_feature_user') == 'allow')
								<div class="col-sm-12 col-md-4 pt-3 pb-3">
									<div class="form-group">
										<label class="custom-switch mb-0">
											<input type="checkbox" name="chat" class="custom-switch-input" @if ($user->member_use_credits_chat) checked @endif>
											<span class="custom-switch-indicator"></span>
											<span class="custom-switch-description">{{ __('Allow Credits for AI Chat') }}</span>
										</label>
									</div>
								</div>
							@endif
							@if (config('settings.image_feature_user') == 'allow')
								<div class="col-sm-12 col-md-4 pt-3 pb-3">
									<div class="form-group">
										<label class="custom-switch mb-0">
											<input type="checkbox" name="image" class="custom-switch-input" @if ($user->member_use_credits_image) checked @endif>
											<span class="custom-switch-indicator"></span>
											<span class="custom-switch-description">{{ __('Allow Credits for AI Images') }}</span>
										</label>
									</div>
								</div>
							@endif
							@if (config('settings.code_feature_user') == 'allow')
								<div class="col-sm-12 col-md-4 pt-3 pb-3">
									<div class="form-group">
										<label class="custom-switch mb-0">
											<input type="checkbox" name="code" class="custom-switch-input" @if ($user->member_use_credits_code) checked @endif>
											<span class="custom-switch-indicator"></span>
											<span class="custom-switch-description">{{ __('Allow Credits for AI Code') }}</span>
										</label>
									</div>
								</div>
							@endif
							@if (config('settings.voiceover_feature_user') == 'allow')
								<div class="col-sm-12 col-md-4 pt-3 pb-3">
									<div class="form-group">
										<label class="custom-switch mb-0">
											<input type="checkbox" name="voiceover" class="custom-switch-input" @if ($user->member_use_credits_voiceover) checked @endif>
											<span class="custom-switch-indicator"></span>
											<span class="custom-switch-description">{{ __('Allow Credits for AI Voiceovers') }}</span>
										</label>
									</div>
								</div>
							@endif
							@if (config('settings.whisper_feature_user') == 'allow')
								<div class="col-sm-12 col-md-4 pt-3 pb-3">
									<div class="form-group">
										<label class="custom-switch mb-0">
											<input type="checkbox" name="speech" class="custom-switch-input" @if ($user->member_use_credits_speech) checked @endif>
											<span class="custom-switch-indicator"></span>
											<span class="custom-switch-description">{{ __('Allow Credits for AI Speech to Text') }}</span>
										</label>
									</div>
								</div>
							@endif
						</div>

						<div class="row border-top pt-4 mt-3">
							<div class="col-sm-6 col-md-6">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('Job Role') }}</label>
										<input type="text" class="form-control @error('job_role') is-danger @enderror" name="job_role" value="{{ $user->job_role }}">
										@error('job_role')
											<p class="text-danger">{{ $errors->first('job_role') }}</p>
										@enderror
									</div>
								</div>
							</div>						
							<div class="col-sm-6 col-md-6">
								<div class="input-box">
									<div class="form-group">								
										<label class="form-label fs-12">{{ __('Phone Number') }}</label>
										<input type="tel" class="fs-12 form-control @error('phone_number') is-danger @enderror" id="phone-number" name="phone_number" value="{{ $user->phone_number }}">
										@error('phone_number')
											<p class="text-danger">{{ $errors->first('phone_number') }}</p>
										@enderror
									</div>
								</div>
							</div>			
							<div class="col-sm-6 col-md-6">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('Company Name') }}</label>
										<input type="text" class="form-control @error('company') is-danger @enderror" name="company" value="{{ $user->company }}">
										@error('company')
											<p class="text-danger">{{ $errors->first('company') }}</p>
										@enderror
									</div>
								</div>
							</div>
							<div class="col-sm-6 col-md-6">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('Company Website') }}</label>
										<input type="text" class="form-control @error('website') is-danger @enderror" name="website" value="{{ $user->website }}">
										@error('website')
											<p class="text-danger">{{ $errors->first('website') }}</p>
										@enderror
									</div>
								</div>
							</div>
							<div class="col-md-12">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('Address Line') }}</label>
										<input type="text" class="form-control @error('address') is-danger @enderror" name="address" value="{{ $user->address }}">
										@error('address')
											<p class="text-danger">{{ $errors->first('address') }}</p>
										@enderror
									</div>
								</div>
							</div>
							<div class="col-sm-6 col-md-4">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('City') }}</label>
										<input type="text" class="form-control @error('city') is-danger @enderror" name="city" value="{{ $user->city }}">
										@error('city')
											<p class="text-danger">{{ $errors->first('city') }}</p>
										@enderror
									</div>
								</div>
							</div>
							<div class="col-sm-6 col-md-3">
								<div class="input-box">
									<div class="form-group">
										<label class="form-label fs-12">{{ __('Postal Code') }}</label>
										<input type="text" class="form-control @error('postal_code') is-danger @enderror" name="postal_code" value="{{ $user->postal_code }}">
										@error('postal_code')
											<p class="text-danger">{{ $errors->first('postal_code') }}</p>
										@enderror
									</div>
								</div>
							</div>
							<div class="col-md-5">
								<div class="form-group">
									<label class="form-label fs-12">{{ __('Country') }}</label>
									<select id="user-country" name="country" data-placeholder="Select Your Country:">	
										@foreach(config('countries') as $value)
											<option value="{{ $value }}" @if($user->country == $value) selected @endif>{{ $value }}</option>
										@endforeach										
									</select>
									@error('country')
										<p class="text-danger">{{ $errors->first('country') }}</p>
									@enderror
								</div>
							</div>
						</div>
						<div class="card-footer border-0 text-right mb-2 pr-0">							
							<a href="{{ route('user.team') }}" class="btn btn-cancel mr-2">{{ __('Return') }}</a>
							<button type="submit" class="btn btn-primary">{{ __('Update') }}</button>
						</div>
					</form>
				</div>				
			</div>
		</div>
	</div>
	<!-- EDIT USER PROFILE PAGE -->
@endsection

@section('js')
	<!-- Telephone Input JS -->
	<script src="{{URL::asset('plugins/telephoneinput/telephoneinput.js')}}"></script>
	<script>
		$(function() {
			"use strict";
			
			$("#phone-number").intlTelInput();
		});
	</script>
@endsection